@@ -45,8 +45,7 @@ class Steps:
         schema_dict = pkgutil.get_data(__name__, "../schema/mpyl_config.schema.yml")
 
         if schema_dict:
-            schema = yaml.load(schema_dict.decode('utf-8'))
-            validate(properties.config, schema)
+            validate(properties.config, schema_dict.decode('utf-8'))
 
         self._logger = logger
 
@@ -88,20 +87,16 @@ class Steps:
         return result
 
     @staticmethod
-    def _find_required_artifact(project: Project, step: Step) -> Optional[Artifact]:
-        if step.required_artifact is None:
+    def _find_required_artifact(project: Project, required_artifact: Optional[ArtifactType]) -> Optional[Artifact]:
+        if not required_artifact or required_artifact == ArtifactType.NONE:
             return None
 
-        required_artifact = step.required_artifact
-        if step.required_artifact and required_artifact != ArtifactType.NONE:
-            output: Optional[Output] = Output.try_read(project.target_path, Stage.BUILD)
-            if output is None or output.produced_artifact \
-                    and output.produced_artifact.artifact_type != required_artifact:
-                raise ValueError(
-                    f"Artifact {required_artifact} required for {project.name}, found: {output}")
+        for stage in Stage:
+            output: Optional[Output] = Output.try_read(project.target_path, stage)
+            if output and output.produced_artifact and output.produced_artifact.artifact_type == required_artifact:
+                return output.produced_artifact
 
-            return output.produced_artifact
-        return None
+        raise ValueError(f"Artifact {required_artifact} required for {project.name} not found")
 
     def _execute_stage(self, stage: Stage, project: Project, dry_run: bool = False) -> Output:
         stage_name = project.stages.for_stage(stage)
@@ -111,11 +106,13 @@ class Steps:
         executor = self._find_executor(stage, stage_name)
         if executor:
             try:
-                artifact: Optional[Artifact] = self._find_required_artifact(project, executor)
+                self._logger.info(f'Executing {stage} for {project.name}')
+                artifact: Optional[Artifact] = self._find_required_artifact(project, executor.required_artifact)
                 result = Output(success=True, message='')
                 if executor.before:
                     result = self._execute(executor.before, project, self._properties,
-                                           self._find_required_artifact(project, executor.before), dry_run)
+                                           self._find_required_artifact(project, executor.before.required_artifact),
+                                           dry_run)
                 if result.success:
                     result = self._execute(executor, project, self._properties, artifact, dry_run)
                 if executor.after:
@@ -131,7 +128,7 @@ class Steps:
         else:
             self._logger.warning(f"No executor found for {stage_name} in stage {stage}")
 
-        return Output(success=False, message=f"Executor {stage.value} not defined on project {project.name}")
+        return Output(success=False, message=f"Executor '{stage_name}' for '{stage.value}' not known or registered")
 
     def execute(self, stage: Stage, project: Project, dry_run: bool = False) -> StepResult:
         step_output = self._execute_stage(stage, project, dry_run)
